==> cd_directory_manager-0.5.0.tar.gz: cd_directory_manager-0.5.0/README.md <==
# CD_Directory_Manager: Directory Manager Package
CD is for Code Docta.


The `CD_Directory_Manager` project houses the `Directory Manager` package, a comprehensive set of utilities designed for efficient file and directory management, ZIP operations, and more.

## Installation

To install the `Directory Manager` package, you can use pip:

```bash
pip install cd-directory-manager
```
Update
```commandline
pip install -U cd-directory-manager
```
## Features

The `Directory Manager` package contains the following classes, each in its separate file:

### 1. Directory Manager

- **File**: `directory_manager.py`
- **Description**: Manages directory-related operations like creating, deleting, listing files, and more.


### 2. File Manager

- **File**: `file_manager.py`
- **Description**: Handles various file operations like reading, writing, and managing different file formats such as JSON, CSV, HTML, and Pickle.


### 3. Path Manager

- **File**: `path_manager.py`
- **Description**: Provides utilities for handling and manipulating file paths in a cross-platform manner.


### 4. Zip Manager

- **File**: `zipper.py`
- **Description**: Manages ZIP-related operations, including zipping and unzipping files and directories.

## Usage

Each class provides static methods that can be used directly without instantiating the class. For detailed usage, refer to the docstrings within each class file.

Example:

```python
from cd_directory_manager import FileManager as fm

data = fm.read_json("path_to_json_file.json")
```
See more examples in examples folder.

## Contributing

Contributions are welcome! Please open an issue or submit a pull request on GitHub.

## License

This project is licensed under the MIT License. See the `LICENSE` file for details.

More documentation at:
[Code Docta](https://codedocta.com "Code Docta")


# To Do

unitest

==> cd_directory_manager-0.6.0.tar.gz: cd_directory_manager-0.6.0/README.md <==
# CD_Directory_Manager: Directory Manager Package
CD is for Code Docta.


The `CD_Directory_Manager` project houses the `Directory Manager` package, a comprehensive set of utilities designed for efficient file and directory management, ZIP operations, and more.

## Installation

To install the `Directory Manager` package, you can use pip:

```bash
pip install cd-directory-manager
```
Update
```commandline
pip install -U cd-directory-manager
```
## Features

The `Directory Manager` package contains the following classes, each in its separate file:

### 1. Directory Manager

- **File**: `directory_manager.py`
- **Description**: Manages directory-related operations like creating, deleting, listing files, and more.


### 2. File Manager

- **File**: `file_manager.py`
- **Description**: Handles various file operations like reading, writing, and managing different file formats such as JSON, CSV, HTML, and Pickle.


### 3. Path Manager

- **File**: `path_manager.py`
- **Description**: Provides utilities for handling and manipulating file paths in a cross-platform manner.


### 4. Zip Manager

- **File**: `zipper.py`
- **Description**: Manages ZIP-related operations, including zipping and unzipping files and directories.

## Usage

Each class provides static methods that can be used directly without instantiating the class. For detailed usage, refer to the docstrings within each class file.

# Example:
# See all exampled in examples folder.
## Use the same import fo all modules.

### Directory/Folder Management

```python
import cd_directory_manager as dm

dm.folder_mngr.delete_directory()
```
### File Management
```python
data = dm.file_mngr.read_json("path_to_json_file.json")
```
### Path Management
```python
dm.path_mngr()
```
### Zip Management
```python
dm.zip_mngr.zip_file()
```

See more examples in examples folder.

## Contributing

Contributions are welcome! Please open an issue or submit a pull request on GitHub.

## License

This project is licensed under the MIT License. See the `LICENSE` file for details.

More documentation at:
[Code Docta](https://codedocta.com "Code Docta")


# To Do

unitest
